/*
	File: fn_invSlotsEmpty.sqf
	Author: Vilem (BIS) --modified by Robalo

	Description:
	Returns empty inventory slots of given unit.
	
	Parameter(s):
	1: <object> unit 
	
	Returns:
	<array> numbers of empty slots
*/
//#define DEBUG_MODE_FULL
#include "script_component.hpp"

PARAMS_1(_unit);

private["_return","_class","_slotsVar","_slotsCode","_vectorDiff"];
_return = [0,0,0,0,0,0,0,0];

//--Get total slots for unit----------

if ((typeName _unit) != "OBJECT") exitWith {textLogFormat ["INV_ Error: invSlotsEmpty - 1st parameter must be unit! %1", _this];_return};
_class = (configfile >> "cfgvehicles" >> (typeOf _unit)); 
if (!isClass _class) exitWith {textLogFormat ["INV_ Error: cannot get config cfgVehicles class of vehicle: %1", [_unit,_class]];_return};

if (isNumber (_class >> "WeaponSlots")) then {
	_slotsVar = getNumber (_class >> "WeaponSlots");
} else {
  if (isText (_class >> "WeaponSlots")) then {
  	_slotsCode = getText (_class >> "WeaponSlots");
  	_slotsVar = call compile _slotsCode;
  } else {
  	textLogFormat ["INV_ Error: no or bad 'WeaponSlots' entry for given vehicle: %1", [_unit,_class]];
  };
};

if (_slotsVar < 1) exitWith {textLogFormat ["INV_ Error: negative or zero weaponSlots %1 for class: %2", _slotVar, _unit];_return};
_return = [_slotsVar] call FUNC(invCodeToArray);
//TRACE_2("SLOTS TOTAL",_unit,_return);

_vectorDiff = {
  PARAMS_2(_v1,_v2);
  private["_ret","_i"];
  _ret = [];
  for "_i" from 0 to ((count _v1) - 1) do {
  	_ret set [count _ret, (_v1 select _i) - (_v2 select _i)];
  };
  _ret
};

{//for each item in inventory: get slots it is taking & substract from total 
  _return = [_return, ([_x] call FUNC(invSlotType))] call _vectorDiff;
} forEach ([_unit] call FUNC(inv));

//TRACE_2("SLOTS FREE",_unit,_return);
_return
